@@ -88,9 +88,7 @@ def docker_run(run_context: LocalRunContext):
         dockercmd.extend([f"--env-file={envutil.JOB_ENV_FILE}"])
 
     quoted_script = quote_str_for_platform(script)
-    _docker_run_cmd_arg = (
-        f"/bin/bash -c {quoted_script}"  #!!!: Do not split these, it will break the cmd
-    )
+    _docker_run_cmd_arg = f"/bin/bash -l -c {quoted_script}"
 
     dockercmd.extend(
         ["--name", container_name, "-v", f"{_pwd}:/eo_workdir", "-w", "/eo_workdir"]
