@@ -32,14 +32,22 @@ CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help", "--halp"])
 
 
 @click.group(
-    no_args_is_help=False,
     invoke_without_command=True,
     context_settings=CONTEXT_SETTINGS,
 )
 @click.version_option(version=version.__version__)
-def embedops_cli():
-    """EmbedOps CLI Help"""
-    if len(sys.argv) == 1:
+@click.option("--debug", "-d", is_flag=True, help="Enable debug logging")
+@click.pass_context
+def embedops_cli(ctx, debug):
+    """EmbedOps Base Command"""
+
+    if debug:
+        logging.basicConfig(level=logging.DEBUG)
+        _logger.debug("Debug logging enabled")
+    else:
+        logging.basicConfig(level=logging.INFO)
+
+    if ctx.invoked_subcommand is None:
         click.secho("-" * 80, fg="magenta")
         click.secho(
             "\n╭━━━╮╱╱╭╮╱╱╱╱╱╱╭┳━━━╮\n"
@@ -172,6 +180,10 @@ def run(ctx: click.Context, job_name):
 
     telemetry.command_event("jobs_run", {"job_name": job_name})
 
+    # check if token has expired if so try to get a new token
+    if embedops_authorization.is_registery_token_valid() is False:
+        embedops_authorization.login_to_registry()
+
     filename = ctx.obj
     _logger.debug(f"jobs run called with file '{filename}' and job '{job_name}")
 
