@@ -136,6 +136,8 @@ def create_entry():
     ci_run = CIRun()
     new_ci_run = ci_run.create_main()
     _logger.info(new_ci_run.id)
+    # DO NOT REMOVE. need to output ID for eotools-create-run
+    print(new_ci_run.id)
     sys.exit(0)
 
 
